comp2col <-
function(dat, showScale, palette) {
	color <- colorRampPalette(palette,space="rgb")(99)

	perc <-((dat$value - dat$value2)/dat$value2)*100
	prettyP <- pretty(perc,n=8)
	n <- length(prettyP)	
	maxPerc <- max(abs(prettyP))
	scale <- round(((perc/maxPerc) *49)+50)
	
	lineNpc <- convertHeight(unit(0.8,"lines"), "npc", valueOnly = TRUE)

	if (showScale) {	
		# display legend 
		legX <- seq(0,1*((n-1)/n),length.out=n)
		legY <- rep(lineNpc,n)
	 	legW <- rep(1/n,n)
	 	legH <- rep(0.2,n)
		legScale <- round(((prettyP/maxPerc) *49)+50)
	 	legCol <- color[legScale]
	 	leg <- data.frame(X=legX,Y=legY,W=legW,H=legH,Col=legCol)
		
		grid.rect(x=unit(leg$X,"npc"), y=unit(leg$Y,"npc"), width=unit(leg$W,"npc"), 
			height=unit(leg$H,"npc"), just=c("left","bottom"), gp = gpar(fill = as.character(leg$Col)))
		grid.text(paste(prettyP,"%",sep=""),x=unit(leg$X+.5*leg$W, "npc"),y=unit(0, "npc") + unit(0.5,"lines"),
			gp=gpar(cex=0.8))
	}
	return (color[scale])
}

